@@ -4,22 +4,24 @@ from typing import Optional
 from .assets import CertificatesAssets, DomainsAssets, HostsAssets
 from .clouds import Clouds
 from .events import Events
+from .risks import Risks
 from .seeds import Seeds
 
 
 class AsmClient:
-    """Client ASM API class.
-
-    Args:
-        api_key (str): Optional; The API Key provided by Censys.
-        **kwargs: Arbitrary keyword arguments.
-    """
+    """Client ASM API class."""
 
     def __init__(self, api_key: Optional[str] = None, **kwargs):
-        """Inits AsmClient."""
+        """Inits AsmClient.
+
+        Args:
+            api_key (str): Optional; The API Key provided by Censys.
+            **kwargs: Arbitrary keyword arguments.
+        """
         self.seeds = Seeds(api_key, **kwargs)
         self.hosts = HostsAssets(api_key, **kwargs)
         self.certificates = CertificatesAssets(api_key, **kwargs)
         self.domains = DomainsAssets(api_key, **kwargs)
         self.events = Events(api_key, **kwargs)
         self.clouds = Clouds(api_key, **kwargs)
+        self.risks = Risks(api_key, **kwargs)
