@@ -4,11 +4,12 @@ import csv
 import datetime
 import json
 import os.path
-import time
 from typing import List, Optional
 
 from rich.console import Console
 
+from censys.common.deprecation import DeprecationDecorator
+
 Fields = List[str]
 Results = List[dict]
 
@@ -29,6 +30,7 @@ def print_wrote_file(file_path: str):
     console.print(f"Wrote results to file {abs_file_path}", soft_wrap=True)
 
 
+@DeprecationDecorator("CSV output is deprecated and will be removed in the future.")
 def _write_csv(file_path: str, search_results: Results, fields: Fields):
     """Write search results to a new file in CSV format.
 
@@ -36,9 +38,6 @@ def _write_csv(file_path: str, search_results: Results, fields: Fields):
         file_path (str): Name of the file to write to on the disk.
         search_results (Results): A list of results from the query.
         fields (Fields): A list of fields to write as headers.
-
-    Returns:
-        bool: True if wrote to file successfully.
     """
     with open(file_path, "w") as output_file:
         if search_results and isinstance(search_results, list):
@@ -59,9 +58,6 @@ def _write_json(file_path: str, search_results: Results):
     Args:
         file_path (str): Name of the file to write to on the disk.
         search_results (Results): A list of results from the query.
-
-    Returns:
-        bool: True if wrote to file successfully.
     """
     with open(file_path, "w") as output_file:
         # Since the results are already in JSON, just write them to a file.
@@ -75,9 +71,6 @@ def _write_screen(search_results: Results):
 
     Args:
         search_results (Results): A list of results from the query.
-
-    Returns:
-        bool: True if wrote to file successfully.
     """
     print(json.dumps(search_results, indent=4))
 
@@ -86,7 +79,6 @@ def write_file(
     results_list: Results,
     file_format: str = "screen",
     file_path: Optional[str] = None,
-    time_str: str = str(time.time()),
     base_name: str = "censys-query-output",
     csv_fields: Fields = [],
 ):
@@ -96,26 +88,38 @@ def write_file(
         results_list (Results): A list of results from the API query.
         file_format (str): Optional; The format of the output.
         file_path (str): Optional; A path to write results to.
-
-    Returns:
-        bool: True if wrote out successfully.
+        base_name (str): Optional; The base name of the output file.
+        csv_fields (Fields): Optional; A list of fields to write to CSV.
     """
     if file_format and isinstance(file_format, str):
         file_format = file_format.lower()
 
     if not file_path:
         # This method just creates some dynamic file names
-        file_path = ".".join([base_name, time_str, file_format])
+        file_path = ".".join([base_name, file_format])
+    elif file_path.endswith(".json"):
+        file_format = "json"
 
     if file_format == "json":
-        return _write_json(file_path, results_list)
-    if file_format == "csv":
-        return _write_csv(file_path, results_list, fields=csv_fields)
-    return _write_screen(results_list)
+        _write_json(file_path, results_list)
+    elif file_format == "csv":
+        _write_csv(file_path, results_list, fields=csv_fields)
+    else:
+        _write_screen(results_list)
 
 
 def valid_datetime_type(datetime_str: str) -> datetime.datetime:
-    """Custom argparse type for user datetime values from arg."""
+    """Custom argparse type for user datetime values from arg.
+
+    Args:
+        datetime_str (str): A string representing a datetime.
+
+    Raises:
+        ArgumentTypeError: If the datetime string is invalid.
+
+    Returns:
+        datetime.datetime: A datetime object.
+    """
     try:
         return datetime.datetime.strptime(datetime_str, "%Y-%m-%d %H:%M")
     except ValueError:
